@@ -137,14 +137,17 @@ def create_docs_for_dir(resource_dir, output_dir, config_file):
             relative_path = os.path.relpath(real_path, resource_dir)
             target_path = os.path.join(target_dir, relative_path.rpartition('.')[0] + ".html")
             print(f">> Generating docs for resource: {relative_path}")
-            robot.libdoc.libdoc(real_path, target_path)
+            return_code = robot.libdoc.libdoc(real_path, target_path)
+            if return_code > 0:
+                raise Exception(f"Libdoc error! Return code: {return_code}")
             print("")
 
     libs = doc_config["libs"]
     for lib in libs:
-        target_path = os.path.join(target_dir, lib.partition("::")[0] + ".html")
-        print(f">> Generating docs for library: {lib}")  
-        return_code = robot.libdoc.libdoc(lib, target_path)
+        lib_str_with_resolved_vars = os.path.expandvars(lib)
+        target_path = os.path.join(target_dir, lib_str_with_resolved_vars.partition("::")[0] + ".html")
+        print(f">> Generating docs for library: {lib_str_with_resolved_vars}")  
+        return_code = robot.libdoc.libdoc(lib_str_with_resolved_vars, target_path)
         if return_code > 0:
             raise Exception(f"Libdoc error! Return code: {return_code}")
         print("")
@@ -195,7 +198,7 @@ def main():
 
     args = parser.parse_args()
 
-    print(f"Creating docs for: {args.resources_dir}")
+    print(f"Creating docs for: {os.path.abspath(args.resources_dir)}")
 
     if os.path.isdir(args.output_dir):
         print(f"Output dir already exists, deleting it: {args.output_dir}")
